Gets hospital bed availability for given city. Currently supported cities:

* `ahmedabad`
* `hyderabad`

Installation:

```
pip3 install hydbedscraper
```

Usage: in your python project

```
from hydbedscraper.main import work

work("name_of_city")
```
